@@ -14,19 +14,16 @@
 #' processBarcodeField(file_path="file_path")
 #' }
 
-processBarcodeField <- function(file_path="", barcodeType="autodetect", region="-1,-1,-1,-1", containsBinaryData="false", pdfPassword="", description="")
-{
+processBarcodeField <- function(file_path="", barcodeType="autodetect", region="-1,-1,-1,-1", containsBinaryData="false", pdfPassword="", description="") {
 		
 	if (!file.exists(file_path)) stop("File Doesn't Exist. Please check the path.")
 
 	querylist = list(barcodeType=barcodeType, region=region, containsBinaryData=containsBinaryData, pdfPassword=pdfPassword, description=description)
 	
 	body=upload_file(file_path)
-	processdetails <- abbyy_POST("processBarcodeField", query=querylist, body=body)
+	process_details <- abbyy_POST("processBarcodeField", query=querylist, body=body)
 	
-	resdf <- do.call(rbind.data.frame, processdetails) # collapse to a data.frame
-	names(resdf) <- names(processdetails[[1]])[1:length(resdf)] # names for the df, adjust for <7
-	row.names(resdf) <- 1:nrow(resdf)	# row.names for the df
+	resdf <- as.data.frame(do.call(rbind, process_details)) # collapse to a data.frame
 
 	# Print some important things
 	cat("Status of the task: ", resdf$status, "\n")
