@@ -26,12 +26,10 @@ processDocument <- function(taskId = NULL, language="English", profile="document
 	querylist = list(taskId = taskId, language=language, profile=profile,textType=textType, imageSource=imageSource, correctOrientation=correctOrientation, 
 						correctSkew=correctSkew,readBarcodes=readBarcodes,exportFormat=exportFormat, description=description, pdfPassword=pdfPassword)
 
-	processdetails <- abbyy_GET("processDocument", query=querylist)
+	process_details <- abbyy_GET("processDocument", query=querylist)
 		
-	resdf <- do.call(rbind.data.frame, processdetails) # collapse to a data.frame
-	names(resdf) <- names(processdetails[[1]])
-	row.names(resdf) <- 1:nrow(resdf)	# row.names for the df
-
+	resdf <- as.data.frame(do.call(rbind, process_details)) # collapse to a data.frame
+	
 	# Print some important things
 	cat("Status of the task: ", resdf$status, "\n")
 
