@@ -9,20 +9,19 @@
 #' processMRZ(file_path="file_path")
 #' }
 
-processMRZ <- function(file_path="")
-{
+processMRZ <- function(file_path="") {
 	
-	if(!file.exists(file_path)) stop("File Doesn't Exist. Please check the path.")
+	if (!file.exists(file_path)) stop("File Doesn't Exist. Please check the path.")
 
 	body=upload_file(file_path)
-	processdetails <- abbyy_POST("processMRZ", body=body)
+	
+	process_details <- abbyy_POST("processMRZ", body=body)
 
-	resdf <- do.call(rbind.data.frame, processdetails) # collapse to a data.frame
-	names(resdf) <- names(processdetails[[1]])[1:length(resdf)] # names for the df, adjust for <7
-	row.names(resdf) <- 1:nrow(resdf)	# row.names for the df
+	resdf <- as.data.frame(do.call(rbind, process_details)) # collapse to a data.frame
 
 	# Print some important things
 	cat("Status of the task: ", resdf$status, "\n")
+	cat("Task ID: ", 			resdf$id, "\n")
 
 	return(invisible(resdf))
 }
\ No newline at end of file
